==> customized-facade-1.0.3-20190628.100523-15-sources.jar: com/bizvane/customized/facade/models/po/CusUrMbrStorageCardTASKDETAILPO.java <==
package com.bizvane.customized.facade.models.po;

import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.NoArgsConstructor;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;

@Builder
@NoArgsConstructor
@AllArgsConstructor
public class CusUrMbrStorageCardTASKDETAILPO implements Serializable {

	/**
	 * 只读. 主键. mbr_storage_card_task_detail
	 * @mbg.generated  2019-06-22 16:30:05
	 */
	@io.swagger.annotations.ApiModelProperty(value = "主键", name = "mbrStorageCardTaskDetail", required = false, example = "")
	private Long mbrStorageCardTaskDetail;
	/**
	 * 只读. 企业id. sys_company_id
	 * @mbg.generated  2019-06-22 16:30:05
	 */
	@io.swagger.annotations.ApiModelProperty(value = "企业id", name = "sysCompanyId", required = false, example = "")
	private Long sysCompanyId;
	/**
	 * 只读. 品牌id. brand_id
	 * @mbg.generated  2019-06-22 16:30:05
	 */
	@io.swagger.annotations.ApiModelProperty(value = "品牌id", name = "brandId", required = false, example = "")
	private Long brandId;
	/**
	 * 只读. 批次号. task_id
	 * @mbg.generated  2019-06-22 16:30:05
	 */
	@io.swagger.annotations.ApiModelProperty(value = "批次号", name = "taskId", required = false, example = "")
	private Long taskId;
	/**
	 * 只读. 会员卡号. vip_card_no
	 * @mbg.generated  2019-06-22 16:30:05
	 */
	@io.swagger.annotations.ApiModelProperty(value = "会员卡号", name = "vipCardNo", required = false, example = "")
	private String vipCardNo;
	/**
	 * 只读. 储值卡号. storage_card_no
	 * @mbg.generated  2019-06-22 16:30:05
	 */
	@io.swagger.annotations.ApiModelProperty(value = "储值卡号", name = "storageCardNo", required = false, example = "")
	private String storageCardNo;
	/**
	 * 只读. 余额. balance
	 * @mbg.generated  2019-06-22 16:30:05
	 */
	@io.swagger.annotations.ApiModelProperty(value = "余额", name = "balance", required = false, example = "")
	private BigDecimal balance;
	/**
	 * 只读. 备注. remark
	 * @mbg.generated  2019-06-22 16:30:05
	 */
	@io.swagger.annotations.ApiModelProperty(value = "备注", name = "remark", required = false, example = "")
	private String remark;
	/**
	 * 只读. 数据有效性 1=有效 0=无效. valid
	 * @mbg.generated  2019-06-22 16:30:05
	 */
	@io.swagger.annotations.ApiModelProperty(value = "数据有效性 1=有效 0=无效", name = "valid", required = false, example = "")
	private Boolean valid;
	/**
	 * 只读. 创建人id. create_user_id
	 * @mbg.generated  2019-06-22 16:30:05
	 */
	@io.swagger.annotations.ApiModelProperty(value = "创建人id", name = "createUserId", required = false, example = "")
	private Long createUserId;
	/**
	 * 只读. 创建人名称. create_user_name
	 * @mbg.generated  2019-06-22 16:30:05
	 */
	@io.swagger.annotations.ApiModelProperty(value = "创建人名称", name = "createUserName", required = false, example = "")
	private String createUserName;
	/**
	 * 只读. 创建日期. create_date
	 * @mbg.generated  2019-06-22 16:30:05
	 */
	@io.swagger.annotations.ApiModelProperty(value = "创建日期", name = "createDate", required = false, example = "")
	private Date createDate;
	/**
	 * 只读. 修改人id. modified_user_id
	 * @mbg.generated  2019-06-22 16:30:05
	 */
	@io.swagger.annotations.ApiModelProperty(value = "修改人id", name = "modifiedUserId", required = false, example = "")
	private Long modifiedUserId;
	/**
	 * 只读. 修改人名称. modified_user_name
	 * @mbg.generated  2019-06-22 16:30:05
	 */
	@io.swagger.annotations.ApiModelProperty(value = "修改人名称", name = "modifiedUserName", required = false, example = "")
	private String modifiedUserName;
	/**
	 * 只读. 修改日期. modified_date
	 * @mbg.generated  2019-06-22 16:30:05
	 */
	@io.swagger.annotations.ApiModelProperty(value = "修改日期", name = "modifiedDate", required = false, example = "")
	private Date modifiedDate;
	/**
	 * 只读. 版本号. version
	 * @mbg.generated  2019-06-22 16:30:05
	 */
	@io.swagger.annotations.ApiModelProperty(value = "版本号", name = "version", required = false, example = "")
	private Integer version;
	/**
	 * 只读. 导入状态：1 成功 2 失败 0 待审核. status
	 * @mbg.generated  2019-06-22 16:30:05
	 */
	@io.swagger.annotations.ApiModelProperty(value = "导入状态：1 成功 2 失败 0 待审核", name = "status", required = false, example = "")
	private Integer status;
	/**
	 * 只读. 失败原因. fail_reason
	 * @mbg.generated  2019-06-22 16:30:05
	 */
	@io.swagger.annotations.ApiModelProperty(value = "失败原因", name = "failReason", required = false, example = "")
	private String failReason;
	/**
	 * 只读. 会员姓名. member_name
	 * @mbg.generated  2019-06-22 16:30:05
	 */
	@io.swagger.annotations.ApiModelProperty(value = "会员姓名", name = "memberName", required = false, example = "")
	private String memberName;
	/**
	 * 只读. 手机号. phone
	 * @mbg.generated  2019-06-22 16:30:05
	 */
	@io.swagger.annotations.ApiModelProperty(value = "手机号", name = "phone", required = false, example = "")
	private String phone;
	/**
	 * 只读. 
	 * @mbg.generated  2019-06-22 16:30:05
	 */
	private static final long serialVersionUID = 1L;

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-22 16:30:05
	 */
	public Long getMbrStorageCardTaskDetail() {
		return mbrStorageCardTaskDetail;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-22 16:30:05
	 */
	public void setMbrStorageCardTaskDetail(Long mbrStorageCardTaskDetail) {
		this.mbrStorageCardTaskDetail = mbrStorageCardTaskDetail;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-22 16:30:05
	 */
	public Long getSysCompanyId() {
		return sysCompanyId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-22 16:30:05
	 */
	public void setSysCompanyId(Long sysCompanyId) {
		this.sysCompanyId = sysCompanyId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-22 16:30:05
	 */
	public Long getBrandId() {
		return brandId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-22 16:30:05
	 */
	public void setBrandId(Long brandId) {
		this.brandId = brandId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-22 16:30:05
	 */
	public Long getTaskId() {
		return taskId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-22 16:30:05
	 */
	public void setTaskId(Long taskId) {
		this.taskId = taskId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-22 16:30:05
	 */
	public String getVipCardNo() {
		return vipCardNo;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-22 16:30:05
	 */
	public void setVipCardNo(String vipCardNo) {
		this.vipCardNo = vipCardNo == null ? null : vipCardNo.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-22 16:30:05
	 */
	public String getStorageCardNo() {
		return storageCardNo;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-22 16:30:05
	 */
	public void setStorageCardNo(String storageCardNo) {
		this.storageCardNo = storageCardNo == null ? null : storageCardNo.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-22 16:30:05
	 */
	public BigDecimal getBalance() {
		return balance;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-22 16:30:05
	 */
	public void setBalance(BigDecimal balance) {
		this.balance = balance;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-22 16:30:05
	 */
	public String getRemark() {
		return remark;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-22 16:30:05
	 */
	public void setRemark(String remark) {
		this.remark = remark == null ? null : remark.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-22 16:30:05
	 */
	public Boolean getValid() {
		return valid;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-22 16:30:05
	 */
	public void setValid(Boolean valid) {
		this.valid = valid;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-22 16:30:05
	 */
	public Long getCreateUserId() {
		return createUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-22 16:30:05
	 */
	public void setCreateUserId(Long createUserId) {
		this.createUserId = createUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-22 16:30:05
	 */
	public String getCreateUserName() {
		return createUserName;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-22 16:30:05
	 */
	public void setCreateUserName(String createUserName) {
		this.createUserName = createUserName == null ? null : createUserName.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-22 16:30:05
	 */
	public Date getCreateDate() {
		return createDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-22 16:30:05
	 */
	public void setCreateDate(Date createDate) {
		this.createDate = createDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-22 16:30:05
	 */
	public Long getModifiedUserId() {
		return modifiedUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-22 16:30:05
	 */
	public void setModifiedUserId(Long modifiedUserId) {
		this.modifiedUserId = modifiedUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-22 16:30:05
	 */
	public String getModifiedUserName() {
		return modifiedUserName;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-22 16:30:05
	 */
	public void setModifiedUserName(String modifiedUserName) {
		this.modifiedUserName = modifiedUserName == null ? null : modifiedUserName.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-22 16:30:05
	 */
	public Date getModifiedDate() {
		return modifiedDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-22 16:30:05
	 */
	public void setModifiedDate(Date modifiedDate) {
		this.modifiedDate = modifiedDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-22 16:30:05
	 */
	public Integer getVersion() {
		return version;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-22 16:30:05
	 */
	public void setVersion(Integer version) {
		this.version = version;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-22 16:30:05
	 */
	public Integer getStatus() {
		return status;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-22 16:30:05
	 */
	public void setStatus(Integer status) {
		this.status = status;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-22 16:30:05
	 */
	public String getFailReason() {
		return failReason;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-22 16:30:05
	 */
	public void setFailReason(String failReason) {
		this.failReason = failReason == null ? null : failReason.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-22 16:30:05
	 */
	public String getMemberName() {
		return memberName;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-22 16:30:05
	 */
	public void setMemberName(String memberName) {
		this.memberName = memberName == null ? null : memberName.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-22 16:30:05
	 */
	public String getPhone() {
		return phone;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-22 16:30:05
	 */
	public void setPhone(String phone) {
		this.phone = phone == null ? null : phone.trim();
	}
}

==> customized-facade-1.0.3-20200421.073754-146-sources.jar: com/bizvane/customized/facade/models/po/CusUrMbrStorageCardTASKDETAILPO.java <==
package com.bizvane.customized.facade.models.po;

import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.NoArgsConstructor;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;

@Builder
@NoArgsConstructor
@AllArgsConstructor
public class CusUrMbrStorageCardTASKDETAILPO implements Serializable {/**
	 * 只读. 主键. mbr_storage_card_task_detail
	 * @mbg.generated  2019-06-28 20:18:19
	 */
	@io.swagger.annotations.ApiModelProperty(value = "主键", name = "mbrStorageCardTaskDetail", required = false, example = "")
	private Long mbrStorageCardTaskDetail;
	/**
	 * 只读. 企业id. sys_company_id
	 * @mbg.generated  2019-06-28 20:18:19
	 */
	@io.swagger.annotations.ApiModelProperty(value = "企业id", name = "sysCompanyId", required = false, example = "")
	private Long sysCompanyId;
	/**
	 * 只读. 品牌id. brand_id
	 * @mbg.generated  2019-06-28 20:18:19
	 */
	@io.swagger.annotations.ApiModelProperty(value = "品牌id", name = "brandId", required = false, example = "")
	private Long brandId;
	/**
	 * 只读. 批次号. task_code
	 * @mbg.generated  2019-06-28 20:18:19
	 */
	@io.swagger.annotations.ApiModelProperty(value = "批次号", name = "taskCode", required = false, example = "")
	private String taskCode;
	/**
	 * 只读. 会员卡号. vip_card_no
	 * @mbg.generated  2019-06-28 20:18:19
	 */
	@io.swagger.annotations.ApiModelProperty(value = "会员卡号", name = "vipCardNo", required = false, example = "")
	private String vipCardNo;
	/**
	 * 只读. 储值卡号. storage_card_no
	 * @mbg.generated  2019-06-28 20:18:19
	 */
	@io.swagger.annotations.ApiModelProperty(value = "储值卡号", name = "storageCardNo", required = false, example = "")
	private String storageCardNo;
	/**
	 * 只读. 余额. balance
	 * @mbg.generated  2019-06-28 20:18:19
	 */
	@io.swagger.annotations.ApiModelProperty(value = "余额", name = "balance", required = false, example = "")
	private BigDecimal balance;
	/**
	 * 只读. 备注. remark
	 * @mbg.generated  2019-06-28 20:18:19
	 */
	@io.swagger.annotations.ApiModelProperty(value = "备注", name = "remark", required = false, example = "")
	private String remark;
	/**
	 * 只读. 数据有效性 1=有效 0=无效. valid
	 * @mbg.generated  2019-06-28 20:18:19
	 */
	@io.swagger.annotations.ApiModelProperty(value = "数据有效性 1=有效 0=无效", name = "valid", required = false, example = "")
	private Boolean valid;
	/**
	 * 只读. 创建人id. create_user_id
	 * @mbg.generated  2019-06-28 20:18:19
	 */
	@io.swagger.annotations.ApiModelProperty(value = "创建人id", name = "createUserId", required = false, example = "")
	private Long createUserId;
	/**
	 * 只读. 创建人名称. create_user_name
	 * @mbg.generated  2019-06-28 20:18:19
	 */
	@io.swagger.annotations.ApiModelProperty(value = "创建人名称", name = "createUserName", required = false, example = "")
	private String createUserName;
	/**
	 * 只读. 创建日期. create_date
	 * @mbg.generated  2019-06-28 20:18:19
	 */
	@io.swagger.annotations.ApiModelProperty(value = "创建日期", name = "createDate", required = false, example = "")
	private Date createDate;
	/**
	 * 只读. 修改人id. modified_user_id
	 * @mbg.generated  2019-06-28 20:18:19
	 */
	@io.swagger.annotations.ApiModelProperty(value = "修改人id", name = "modifiedUserId", required = false, example = "")
	private Long modifiedUserId;
	/**
	 * 只读. 修改人名称. modified_user_name
	 * @mbg.generated  2019-06-28 20:18:19
	 */
	@io.swagger.annotations.ApiModelProperty(value = "修改人名称", name = "modifiedUserName", required = false, example = "")
	private String modifiedUserName;
	/**
	 * 只读. 修改日期. modified_date
	 * @mbg.generated  2019-06-28 20:18:19
	 */
	@io.swagger.annotations.ApiModelProperty(value = "修改日期", name = "modifiedDate", required = false, example = "")
	private Date modifiedDate;
	/**
	 * 只读. 版本号. version
	 * @mbg.generated  2019-06-28 20:18:19
	 */
	@io.swagger.annotations.ApiModelProperty(value = "版本号", name = "version", required = false, example = "")
	private Integer version;
	/**
	 * 只读. 导入状态：1 成功 2 失败 0 待审核. status
	 * @mbg.generated  2019-06-28 20:18:19
	 */
	@io.swagger.annotations.ApiModelProperty(value = "导入状态：1 成功 2 失败 0 待审核", name = "status", required = false, example = "")
	private Integer status;
	/**
	 * 只读. 失败原因. fail_reason
	 * @mbg.generated  2019-06-28 20:18:19
	 */
	@io.swagger.annotations.ApiModelProperty(value = "失败原因", name = "failReason", required = false, example = "")
	private String failReason;
	/**
	 * 只读. 会员姓名. member_name
	 * @mbg.generated  2019-06-28 20:18:19
	 */
	@io.swagger.annotations.ApiModelProperty(value = "会员姓名", name = "memberName", required = false, example = "")
	private String memberName;
	/**
	 * 只读. 手机号. phone
	 * @mbg.generated  2019-06-28 20:18:19
	 */
	@io.swagger.annotations.ApiModelProperty(value = "手机号", name = "phone", required = false, example = "")
	private String phone;
	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 20:18:19
	 */
	private static final long serialVersionUID = 1L;

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 20:18:19
	 */
	public Long getMbrStorageCardTaskDetail() {
		return mbrStorageCardTaskDetail;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 20:18:19
	 */
	public void setMbrStorageCardTaskDetail(Long mbrStorageCardTaskDetail) {
		this.mbrStorageCardTaskDetail = mbrStorageCardTaskDetail;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 20:18:19
	 */
	public Long getSysCompanyId() {
		return sysCompanyId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 20:18:19
	 */
	public void setSysCompanyId(Long sysCompanyId) {
		this.sysCompanyId = sysCompanyId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 20:18:19
	 */
	public Long getBrandId() {
		return brandId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 20:18:19
	 */
	public void setBrandId(Long brandId) {
		this.brandId = brandId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 20:18:19
	 */
	public String getTaskCode() {
		return taskCode;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 20:18:19
	 */
	public void setTaskCode(String taskCode) {
		this.taskCode = taskCode == null ? null : taskCode.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 20:18:19
	 */
	public String getVipCardNo() {
		return vipCardNo;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 20:18:19
	 */
	public void setVipCardNo(String vipCardNo) {
		this.vipCardNo = vipCardNo == null ? null : vipCardNo.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 20:18:19
	 */
	public String getStorageCardNo() {
		return storageCardNo;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 20:18:19
	 */
	public void setStorageCardNo(String storageCardNo) {
		this.storageCardNo = storageCardNo == null ? null : storageCardNo.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 20:18:19
	 */
	public BigDecimal getBalance() {
		return balance;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 20:18:19
	 */
	public void setBalance(BigDecimal balance) {
		this.balance = balance;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 20:18:19
	 */
	public String getRemark() {
		return remark;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 20:18:19
	 */
	public void setRemark(String remark) {
		this.remark = remark == null ? null : remark.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 20:18:19
	 */
	public Boolean getValid() {
		return valid;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 20:18:19
	 */
	public void setValid(Boolean valid) {
		this.valid = valid;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 20:18:19
	 */
	public Long getCreateUserId() {
		return createUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 20:18:19
	 */
	public void setCreateUserId(Long createUserId) {
		this.createUserId = createUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 20:18:19
	 */
	public String getCreateUserName() {
		return createUserName;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 20:18:19
	 */
	public void setCreateUserName(String createUserName) {
		this.createUserName = createUserName == null ? null : createUserName.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 20:18:19
	 */
	public Date getCreateDate() {
		return createDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 20:18:19
	 */
	public void setCreateDate(Date createDate) {
		this.createDate = createDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 20:18:19
	 */
	public Long getModifiedUserId() {
		return modifiedUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 20:18:19
	 */
	public void setModifiedUserId(Long modifiedUserId) {
		this.modifiedUserId = modifiedUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 20:18:19
	 */
	public String getModifiedUserName() {
		return modifiedUserName;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 20:18:19
	 */
	public void setModifiedUserName(String modifiedUserName) {
		this.modifiedUserName = modifiedUserName == null ? null : modifiedUserName.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 20:18:19
	 */
	public Date getModifiedDate() {
		return modifiedDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 20:18:19
	 */
	public void setModifiedDate(Date modifiedDate) {
		this.modifiedDate = modifiedDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 20:18:19
	 */
	public Integer getVersion() {
		return version;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 20:18:19
	 */
	public void setVersion(Integer version) {
		this.version = version;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 20:18:19
	 */
	public Integer getStatus() {
		return status;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 20:18:19
	 */
	public void setStatus(Integer status) {
		this.status = status;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 20:18:19
	 */
	public String getFailReason() {
		return failReason;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 20:18:19
	 */
	public void setFailReason(String failReason) {
		this.failReason = failReason == null ? null : failReason.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 20:18:19
	 */
	public String getMemberName() {
		return memberName;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 20:18:19
	 */
	public void setMemberName(String memberName) {
		this.memberName = memberName == null ? null : memberName.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 20:18:19
	 */
	public String getPhone() {
		return phone;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 20:18:19
	 */
	public void setPhone(String phone) {
		this.phone = phone == null ? null : phone.trim();
	}
}
